<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Windows.Foundation.Metadata

Windows Runtime (WinRT) APIs for for the `Windows.Foundation.Metadata` namespace.

This package provides the `winrt.windows.foundation.metadata` module.
